@@ -4,9 +4,11 @@
   USE base_hooks,                      ONLY: cp__a,&
                                              cp__b,&
                                              cp__w,&
+                                             cp__h,&
                                              cp__l,&
                                              cp_abort,&
                                              cp_warn,&
+                                             cp_hint,&
                                              timeset,&
                                              timestop
 
@@ -19,7 +21,15 @@
 #define __LOCATION__ cp__l(__SHORT_FILE__,__LINE__)
 #define CPWARN(msg) CALL cp__w(__SHORT_FILE__,__LINE__,msg)
 #define CPABORT(msg) CALL cp__b(__SHORT_FILE__,__LINE__,msg)
-#define CPASSERT(cond) IF(.NOT.(cond))CALL cp__a(__SHORT_FILE__,__LINE__)
+! In contrast to CPWARN, the warning counter is not increased
+#define CPHINT(msg) CALL cp__h(__SHORT_FILE__,__LINE__,msg)
+
+! CPASSERT can be elided if NDEBUG is defined.
+#if defined(NDEBUG)
+# define CPASSERT(cond)
+#else
+# define CPASSERT(cond) IF(.NOT.(cond))CALL cp__a(__SHORT_FILE__,__LINE__)
+#endif
 
 ! The MARK_USED macro can be used to mark an argument/variable as used.
 ! It is intended to make it possible to switch on -Werror=unused-dummy-argument,
@@ -27,3 +37,7 @@
 ! This code should be valid for any Fortran variable, is always standard conforming,
 ! and will be optimized away completely by the compiler
 #define MARK_USED(foo) IF(.FALSE.)THEN; DO ; IF(SIZE(SHAPE(foo))==-1) EXIT ;  END DO ; ENDIF
+
+! Calculate version number from 3-components. Can be used for comparison e.g.,
+! CPVERSION(4, 9, 0) <= CPVERSION(__GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__)
+#define CPVERSION(MAJOR, MINOR, UPDATE) ((MAJOR) * 10000 + (MINOR) * 100 + (UPDATE))
