@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 import sys, re
 
 FYPP_SYMBOLS = r"(#|\$|@)"
@@ -5,9 +7,8 @@ FYPP_LINE = r"^\s*" + FYPP_SYMBOLS + r":"
 FYPP_INLINE = r"(" + FYPP_SYMBOLS + r"{|}" + FYPP_SYMBOLS + r")"
 FYPP_RE = re.compile(r"(" + FYPP_LINE + r"|" + FYPP_INLINE + r")")
 
-infile = open(sys.argv[1], 'r')
-for line in infile.readlines():
-    if FYPP_RE.search(line):
+with open(sys.argv[1], "r") as infile:
+    if any(FYPP_RE.search(l) for l in infile):
         sys.exit(0)
 
 sys.exit(1)
