@@ -64,8 +64,4 @@ def gen_povray():
 
 
 #-------------------------------------------------------------------------------
-if(len(sys.argv)==2 and sys.argv[-1]=="--selftest"):
-    pass #TODO implement selftest
-else:
-    main()
-#EOF
+main()
