@@ -4,7 +4,7 @@ SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
 # +-----------------------------------------------------------------------+
 # |  CP2K: A general program to perform molecular dynamics simulations    |
-# |  Copyright (C) 2000 - 2018  CP2K developers group                     |
+# |  Copyright (C) 2000 - 2019  CP2K developers group                     |
 # +-----------------------------------------------------------------------+
 #
 # *****************************************************************************
@@ -26,11 +26,15 @@ export SETUPFILE="${INSTALLDIR}/setup"
 export SHA256_CHECKSUM="${SCRIPTDIR}/checksums.sha256"
 export ARCH_FILE_TEMPLATE="${SCRIPTDIR}/arch_base.tmpl"
 
+# ------------------------------------------------------------------------
+# Make a copy of all options for $SETUPFILE
+# ------------------------------------------------------------------------
+TOOLCHAIN_OPTIONS="$@"
+
 # ------------------------------------------------------------------------
 # Load common variables and tools
 # ------------------------------------------------------------------------
 source "${SCRIPTDIR}"/common_vars.sh
-source "${SCRIPTDIR}"/package_versions.sh
 source "${SCRIPTDIR}"/tool_kit.sh
 
 # ------------------------------------------------------------------------
@@ -58,7 +62,7 @@ OPTIONS:
                           from wget or ones saying that "common name doesn't
                           match requested host name" while at tarball downloading
                           stage, then the recommended solution is to install
-                          the newest wget release.  Alternatively, you can use
+                          the newest wget release. Alternatively, you can use
                           this option to bypass the verification and proceed with
                           the download. Security wise this should still be okay
                           as the installation script will check file checksums
@@ -70,10 +74,10 @@ OPTIONS:
                           --with-PKG option placed AFTER this option on the
                           command line.
 --mpi-mode                Selects which MPI flavour to use. Available options
-                          are: mpich, openmpi and no.  By selecting no, you will
-                          be disabling MPI support.  By default the script
+                          are: mpich, openmpi and no. By selecting no, you will
+                          be disabling MPI support. By default the script
                           will try to determine the flavour based on the MPI library
-                          currently avaliable in your system path. For CRAY (CLE)
+                          currently available in your system path. For CRAY (CLE)
                           systems, the default flavour is mpich. Note that explicitly
                           setting --with-mpich or --with-openmpi options to values
                           other than no will also switch --mpi-mode to the respective
@@ -89,10 +93,18 @@ OPTIONS:
                           --with-acml, --with-mkl or --with-openblas options will
                           switch --math-mode to the respective modes, BUT
                           --with-reflapack option do not have this effect.
+--gpu-ver                 Selects the GPU architecture for which to compile. Available
+                          options are: K20X, K40, K80, P100, V100, no. Default: no.
+                          The script will determine the correct corresponding value for
+                          nvcc's '-arch' flag.
+--libint-lmax             Maximum supported angular momentum by libint.
+                          Higher values will increase build time and library size.
+                          Default = 5
+--dry-run                 Write only config files, but dont' actually build packages.
 
 The --enable-FEATURE options follow the rules:
   --enable-FEATURE=yes    Enable this particular feature
-  --enable-FEATHRE=no     Disable this particular feature
+  --enable-FEATURE=no     Disable this particular feature
   --enable-FEATURE        The option keyword alone is equivalent to
                           --enable-FEATURE=yes
 
@@ -132,17 +144,11 @@ The --with-PKG options follow the rules:
 
   --with-gcc              The GCC compiler to use to compile CP2K
                           Default = system
-  --with-binutils         GNU binutils
-                          Default = system
-  --with-make             GNU make
-                          Default = system
   --with-cmake            Cmake utilities, required for building ParMETIS
                           Default = no
   --with-valgrind         Valgrind memory debugging tool, only used for
                           debugging purposes.
                           Default = no
-  --with-lcov             LCOV code coverage utility, mainly used by CP2K developers
-                          Default = no
   --with-openmpi          OpenMPI, important if you want parallel version
                           of CP2K.
                           Default = system
@@ -170,7 +176,7 @@ The --with-PKG options follow the rules:
                           the one specified by --with-scalapack option.
                           Default = system
   --with-openblas         OpenBLAS is a free high performance LAPACK and BLAS library,
-                          the sucessor to GotoBLAS.
+                          the successor to GotoBLAS.
                           Default = install
   --with-scalapack        Parallel linear algebra library, needed for parallel
                           calculations.
@@ -180,7 +186,7 @@ The --with-PKG options follow the rules:
                           --with-libsmm=install, then instead of actually compiling
                           the library (which may take a long time), the script will
                           try to download a preexisting version from the CP2K website
-                          that is compatable with your system.
+                          that is compatible with your system.
                           Default = no
   --with-libxsmm          Small matrix multiplication library for x86_64 systems. If
                           your system arch is x86_64, then you can use libxsmm
@@ -188,13 +194,13 @@ The --with-PKG options follow the rules:
                           Default = install
   --with-elpa             Eigenvalue SoLvers for Petaflop-Applications library.
                           Fast library for large parallel jobs.
-                          Default = no
+                          Default = install
   --with-ptscotch         PT-SCOTCH, only used if PEXSI is used
                           Default = no
   --with-parmetis         ParMETIS, and if --with-parmetis=install will also install
                           METIS, only used if PEXSI is used
                           Default = no
-  --with-metis            METIS, --with-metis=install actuall does nothing, because
+  --with-metis            METIS, --with-metis=install actually does nothing, because
                           METIS is installed together with ParMETIS.  This option
                           is used to specify the METIS library if it is pre-installed
                           else-where. Only used if PEXSI is used
@@ -205,10 +211,26 @@ The --with-PKG options follow the rules:
                           Default = no
   --with-quip             Enable interface to QUIP library
                           Default = no
+  --with-plumed           Enable interface to the PLUMED library.
+                          Default = no
+  --with-sirius           Enable interface to the plane wave SIRIUS library.
+                          This package requires: gsl, libspg, elpa, scalapack, hdf5 and libxc.
+                          Default = install
+  --with-gsl              Enable the gnu scientific library
+                          Default = install
+  --with-libvdwxc         Enable support of Van der Waals interactions in SIRIUS. Support provided by libvdwxc
+                          Default = install
+  --with-spglib           Enable the spg library (search of symmetry groups)
+                          This package depends on cmake.
+                          Default = install
+  --with-hdf5             Enable the hdf5 library (used by the sirius library)
+                          Default = install
+  --with-spfft            Enable the spare fft used in SIRIUS (hard dependency)
+                          Default = install
 
 FURTHER INSTRUCTIONS
 
-All packages to be installed locally will be downloaded and build inside
+All packages to be installed locally will be downloaded and built inside
 ./build, and then installed into package specific directories inside
 ./install.
 
@@ -220,7 +242,7 @@ the same location as it was first created, as it contains tools and libraries
 your version of CP2K binary will depend on.
 
 It should be safe to terminate running of this script in the middle of a
-build process.  The script will know if a package has been successfully
+build process. The script will know if a package has been successfully
 installed, and will just carry on and recompile and install the last
 package it is working on. This is true even if you lose the content of
 the entire ./build directory.
@@ -237,11 +259,11 @@ EOF
 # PACKAGE LIST: register all new dependent tools and libs here. Order
 # is important, the first in the list gets installed first
 # ------------------------------------------------------------------------
-tool_list="binutils lcov valgrind make cmake gcc"
+tool_list="gcc cmake valgrind"
 mpi_list="mpich openmpi"
 math_list="mkl acml openblas reflapack"
-lib_list="fftw libint libxc libsmm libxsmm scalapack elpa \
-          ptscotch parmetis metis superlu pexsi quip"
+lib_list="fftw libint libxc libsmm libxsmm scalapack elpa plumed \
+          spfft ptscotch parmetis metis superlu pexsi quip gsl spglib hdf5 libvdwxc sirius"
 package_list="$tool_list $mpi_list $math_list $lib_list"
 # ------------------------------------------------------------------------
 
@@ -255,9 +277,7 @@ done
 # ------------------------------------------------------------------------
 
 # tools to turn on by default:
-with_binutils=__SYSTEM__
 with_gcc=__SYSTEM__
-with_make=__SYSTEM__
 
 # libs to turn on by default, the math and mpi libraries are chosen by there respective modes:
 with_fftw=__INSTALL__
@@ -265,7 +285,6 @@ with_libint=__INSTALL__
 with_libxsmm=__INSTALL__
 with_libxc=__INSTALL__
 with_scalapack=__INSTALL__
-
 # default math library settings, FAST_MATH_MODE picks the math library
 # to use, and with_* defines the default method of installation if it
 # is picked. For non-CRAY systems defaults to mkl if $MKLROOT is
@@ -278,7 +297,16 @@ fi
 with_acml=__SYSTEM__
 with_mkl=__SYSTEM__
 with_openblas=__INSTALL__
-with_reflapack=__INSTALL__
+with_reflapack=__DONTUSE__
+
+# sirius is activated by default
+with_sirius="__INSTALL__"
+with_gsl="__INSTALL__"
+with_spglib="__INSTALL__"
+with_hdf5="__INSTALL__"
+with_elpa="__INSTALL__"
+with_libvdwxc="__INSTALL__"
+with_spfft=__INSTALL__
 
 # for MPI, we try to detect system MPI variant
 with_openmpi=__SYSTEM__
@@ -296,14 +324,15 @@ if (command -v mpirun >&- 2>&-) ; then
         export MPI_MODE=mpich
     fi
 else
-    report_warning $LINENO "No MPI installation detected on you system. Ignore this message if you are using Cray Linux Environment"
-    MPI_MODE=no
+    report_warning $LINENO "No MPI installation detected on your system. Ignore this message if you are using Cray Linux Environment"
+    export MPI_MODE=no
 fi
 
 # number of processors to use
 export NPROCS=$(get_nprocs)
 
 # default enable options
+dry_run=__FALSE__
 enable_tsan=__FALSE__
 enable_gcc_master=__FALSE__
 enable_libxsmm_master=__FALSE__
@@ -311,11 +340,16 @@ enable_omp=__TRUE__
 if (command -v nvcc >&- 2>&-) ; then
    echo "nvcc found, enabling CUDA by default"
    enable_cuda=__TRUE__
+   export GPUVER=no
 else
    echo "nvcc not found, disabling CUDA by default"
    enable_cuda=__FALSE__
+   export GPUVER=no
 fi
 
+# default for libint
+export LIBINT_LMAX=5
+
 # defaults for CRAY Linux Environment
 if [ "$CRAY_LD_LIBRARY_PATH" ] ; then
     enable_cray=__TRUE__
@@ -333,6 +367,7 @@ else
     enable_cray=__FALSE__
 fi
 
+
 # ------------------------------------------------------------------------
 # parse user options
 # ------------------------------------------------------------------------
@@ -351,7 +386,7 @@ while [ $# -ge 1 ] ; do
                 eval with_${ii}=__INSTALL__
             done
             # default mpi-mode to MPICH
-            MPI_MODE=mpich
+            export MPI_MODE=mpich
             ;;
         --mpi-mode=*)
             user_input="${1#*=}"
@@ -395,6 +430,41 @@ while [ $# -ge 1 ] ; do
                     "--math-mode currently only supports mkl, acml, openblas and reflapack as options"
             esac
             ;;
+        --gpu-ver=*)
+            user_input="${1#*=}"
+            case "$user_input" in
+                K20X)
+                    export GPUVER=K20X
+                    ;;
+                K40)
+                    export GPUVER=K40
+                    ;;
+                K80)
+                    export GPUVER=K80
+                    ;;
+                P100)
+                    export GPUVER=P100
+                    ;;
+                V100)
+                    export GPUVER=V100
+                    ;;
+                no)
+                    export GPUVER=no
+                    ;;
+                *)
+                    export GPUVER=no
+                    report_error ${LINENO} \
+                    "--gpu-ver currently only supports K20X, K40, K80, P100, V100 and no as options"
+                    exit 1
+            esac
+            ;;
+        --libint-lmax=*)
+            user_input="${1#*=}"
+            export LIBINT_LMAX="$user_input"
+            ;;
+        --dry-run)
+            dry_run="__TRUE__"
+            ;;
         --enable-tsan*)
             enable_tsan=$(read_enable $1)
             if [ $enable_tsan = "__INVALID__" ] ; then
@@ -440,18 +510,9 @@ while [ $# -ge 1 ] ; do
         --with-gcc*)
             with_gcc=$(read_with $1)
             ;;
-        --with-binutils*)
-            with_binutils=$(read_with $1)
-            ;;
-        --with-make*)
-            with_make=$(read_with $1)
-            ;;
         --with-cmake*)
             with_cmake=$(read_with $1)
             ;;
-        --with-lcov*)
-            with_lcov=$(read_with $1)
-            ;;
         --with-valgrind*)
             with_valgrind=$(read_with $1)
             ;;
@@ -527,10 +588,39 @@ while [ $# -ge 1 ] ; do
         --with-quip*)
             with_quip=$(read_with $1)
             ;;
-        *)
+        --with-plumed*)
+            with_plumed=$(read_with $1)
+            ;;
+        --with-sirius*)
+            with_sirius=$(read_with $1)
+            ;;
+        --with-gsl*)
+            with_gsl=$(read_with $1)
+            ;;
+        --with-spglib*)
+            with_spglib=$(read_with $1)
+            ;;
+        --with-hdf5*)
+            with_hdf5=$(read_with $1)
+            ;;
+        --with-libvdwxc*)
+            with_libvdwxc=$(read_with $1)
+            ;;
+        --with-spfft*)
+            with_spfft=$(read_with $1)
+            ;;
+        --help*)
             show_help
             exit 0
             ;;
+        -h*)
+            show_help
+            exit 0
+            ;;
+        *)
+            report_error "Unknown flag: $1"
+            exit 1
+            ;;
     esac
     shift
 done
@@ -543,7 +633,6 @@ export ENABLE_CRAY=$enable_cray
 [ "$enable_gcc_master" = "__TRUE__" ] && export gcc_ver=master
 [ "$enable_libxsmm_master" = "__TRUE__" ] && export libxsmm_ver=master
 [ "$with_valgrind" != "__DONTUSE__"  ] && export ENABLE_VALGRIND="__TRUE__"
-[ "$with_lcov" != "__DONTUSE__" ] && export ENABLE_COVERAGE="__TRUE__"
 
 # ------------------------------------------------------------------------
 # Check and solve known conflicts before installations proceed
@@ -552,11 +641,11 @@ export ENABLE_CRAY=$enable_cray
 # GCC thread sanitizer conflicts
 if [ $ENABLE_TSAN = "__TRUE__" ] ; then
     if [ "$with_openblas" != "__DONTUSE__" ] ; then
-        echo "TSAN is enabled, canoot use openblas, we will use reflapack instead"
+        echo "TSAN is enabled, cannot use openblas, we will use reflapack instead"
         [ "$with_reflapack" = "__DONTUSE__" ] && with_reflapack="__INSTALL__"
         export FAST_MATH_MODE=reflapack
     fi
-    echo "TSAN is enabled, canoot use libsmm"
+    echo "TSAN is enabled, cannot use libsmm"
     with_libsmm="__DONTUSE__"
 fi
 
@@ -582,6 +671,14 @@ if [ $MPI_MODE = no ] ; then
         echo "Not using MPI, so PEXSI is disabled."
         with_pexsi="__DONTUSE__"
     fi
+    if [ "$with_sirius" != "__DONTUSE__" ] ; then
+        echo "Not using MPI, so sirius is disabled"
+        with_sirius="__DONTUSE__"
+    fi
+    if [ "$with_spfft" != "__DONTUSE__" ] ; then
+        echo "Not using MPI, so spfft is disabled"
+        with_spfft="__DONTUSE__"
+    fi
 else
     # if gcc is installed, then mpi needs to be installed too
     if [ "$with_gcc" = "__INSTALL__" ] ; then
@@ -591,6 +688,14 @@ else
     fi
 fi
 
+# If CUDA is enabled, make sure the GPU version has been defined
+if [ $ENABLE_CUDA = __TRUE__ ] ; then
+    if [ "$GPUVER" = no ] ; then
+        report_error "CUDA enabled, please choose GPU architecture to compile for with --gpu-ver"
+        exit 1
+    fi
+fi
+
 # PESXI and its dependencies
 if [ "$with_pexsi" = "__DONTUSE__" ] ; then
     if [ "$with_ptscotch" != "__DONTUSE__" ] ; then
@@ -631,13 +736,46 @@ else
         exit 1
     fi
 fi
+
 # ParMETIS requires cmake, it also installs METIS if it is chosen
-# __INSTALL__ option
 if [ "$with_parmetis" = "__INSTALL__" ] ; then
     [ "$with_cmake" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
     with_metis="__INSTALL__"
 fi
 
+# spg library requires cmake.
+if [ "$with_spglib" = "__INSTALL__" ] ; then
+    [ "$with_cmake" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
+fi
+
+# SIRIUS dependencies. Remove the gsl library from the dependencies if SIRIUS is not activated
+if [ "$with_sirius" = "__INSTALL__" ] ; then
+    if [ "$with_spfft" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working spfft library use --with-spfft option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+    if [ "$with_gsl" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working gsl library use --with-gsl option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+    if [ "$with_libxc" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working libxc library use --with-libxc option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+    if [ "$with_fftw" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working fftw library use --with-fftw option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+    if [ "$with_spglib" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working spglib library use --with-spglib option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+    if [ "$with_hdf5" = "__DONTUSE__" ] ; then
+        report_error "For SIRIUS to work you need a working hdf5 library use --with-hdf5 option to specify if you wish to install the library or specify its location."
+        exit 1
+    fi
+fi
+
 # ------------------------------------------------------------------------
 # Preliminaries
 # ------------------------------------------------------------------------
@@ -656,6 +794,7 @@ export CP_LDFLAGS="-Wl,--enable-new-dtags"
 cat <<EOF > "$SETUPFILE"
 #!/bin/bash
 source "${SCRIPTDIR}/tool_kit.sh"
+export CP2K_TOOLCHAIN_OPTIONS="${TOOLCHAIN_OPTIONS}"
 EOF
 
 # ------------------------------------------------------------------------
@@ -740,314 +879,76 @@ export F90FLAGS=${F90FLAGS:-"-O2 -g -Wno-error"}
 export F77FLAGS=${F77FLAGS:-"-O2 -g -Wno-error"}
 export CXXFLAGS=${CXXFLAGS:-"-O2 -g -Wno-error"}
 
-# need to setup tools after all of the tools are built. We should use
-# consistent pairs of gcc and binutils etc for make. So we use system
-# tool sets to compile the tool sets used to compile CP2K
-for ii in $tool_list ; do
+# Select the correct compute number based on the GPU architecture
+case $GPUVER in
+    K20X)
+        export ARCH_NUM=35
+        ;;
+    K40)
+        export ARCH_NUM=35
+        ;;
+    K80)
+        export ARCH_NUM=37
+        ;;
+    P100)
+        export ARCH_NUM=60
+        ;;
+    V100)
+        export ARCH_NUM=70
+        ;;
+    no)
+        export ARCH_NUM=no
+        ;;
+    *)
+        report_error ${LINENO} \
+        "--gpu-ver currently only supports K20X, K40, K80, P100, V100 as options"
+esac
+
+# write toolchain environment
+export -p > "${INSTALLDIR}"/toolchain.env
+
+# write toolchain config
+echo "tool_list=\"${tool_list}\"" > "${INSTALLDIR}"/toolchain.conf
+for ii in $package_list ; do
     install_mode="$(eval echo \${with_${ii}})"
-    "${SCRIPTDIR}"/install_${ii}.sh "$install_mode"
-done
-for ii in $tool_list ; do
-    load "${BUILDDIR}/setup_${ii}"
+    echo "with_${ii}=\"${install_mode}\"" >> "${INSTALLDIR}"/toolchain.conf
 done
 
+
 # ------------------------------------------------------------------------
-# Install or compile packages using newly installed tools
+# Build packages unless dry-run mode is enabled.
 # ------------------------------------------------------------------------
-
-# setup compiler flags, leading to nice stack traces on crashes but
-# still optimised
-CFLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-FFLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-F77FLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-F90FLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-FCFLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-CXXFLAGS="-O2 -ftree-vectorize -g -fno-omit-frame-pointer -march=native -ffast-math $TSANFLAGS"
-
-export CFLAGS=$(allowed_gcc_flags $CFLAGS)
-export FFLAGS=$(allowed_gfortran_flags $FFLAGS)
-export F77FLAGS=$(allowed_gfortran_flags $F77FLAGS)
-export F90FLAGS=$(allowed_gfortran_flags $F90FLAGS)
-export FCFLAGS=$(allowed_gfortran_flags $FCFLAGS)
-export CXXFLAGS=$(allowed_gxx_flags $CXXFLAGS)
-
-export LDFLAGS="$TSANFLAGS"
-
-# get system arch information using OpenBLAS prebuild
-"${SCRIPTDIR}"/get_openblas_arch.sh; load "${BUILDDIR}/openblas_arch"
-
-# MPI libraries
-case "$MPI_MODE" in
-    mpich)
-        "${SCRIPTDIR}"/install_mpich.sh "${with_mpich}"; load "${BUILDDIR}/setup_mpich"
-        ;;
-    openmpi)
-        "${SCRIPTDIR}"/install_openmpi.sh "${with_openmpi}"; load "${BUILDDIR}/setup_openmpi"
-        ;;
-esac
-
-# math core libraries, need to use reflapack for valgrind builds, as
-# many fast libraries are not necesarily valgrind clean
-export REF_MATH_CFLAGS=''
-export REF_MATH_LDFLAGS=''
-export REF_MATH_LIBS=''
-export FAST_MATH_CFLAGS=''
-export FAST_MATH_LDFLAGS=''
-export FAST_MATH_LIBS=''
-
-"${SCRIPTDIR}"/install_reflapack.sh "${with_reflapack}"; load "${BUILDDIR}/setup_reflapack"
-case "$FAST_MATH_MODE" in
-    mkl)
-        "${SCRIPTDIR}"/install_mkl.sh "${with_mkl}"; load "${BUILDDIR}/setup_mkl"
-        ;;
-    acml)
-        "${SCRIPTDIR}"/install_acml.sh "${with_acml}"; load "${BUILDDIR}/setup_acml"
-        ;;
-    openblas)
-        "${SCRIPTDIR}"/install_openblas.sh "${with_openblas}"; load "${BUILDDIR}/setup_openblas"
-        ;;
-    cray)
-        # note the space is intentional so that the variable is
-        # non-empty and can pass require_env checks
-        export FAST_MATH_LDFLAGS="${FAST_MATH_LDFLAGS} "
-        export FAST_MATH_LIBS="${FAST_MATH_LIBS} ${CRAY_EXTRA_LIBS}"
-        ;;
-esac
-
-if [ $ENABLE_VALGRIND = "__TRUE__" ] ; then
-    export MATH_CFLAGS="${REF_MATH_CFLAGS}"
-    export MATH_LDFLAGS="${REF_MATH_LDFLAGS}"
-    export MATH_LIBS="${REF_MATH_LIBS}"
+if [ "$dry_run" == "__TRUE__" ] ; then
+    echo "Wrote only configuration files (--dry-run)."
 else
-    export MATH_CFLAGS="${FAST_MATH_CFLAGS}"
-    export MATH_LDFLAGS="${FAST_MATH_LDFLAGS}"
-    export MATH_LIBS="${FAST_MATH_LIBS}"
+    ./scripts/install_gcc.sh
+    ./scripts/setup_buildtools.sh
+    ./scripts/install_cmake.sh
+    ./scripts/install_valgrind.sh
+    ./scripts/install_mpich.sh
+    ./scripts/install_openmpi.sh
+    ./scripts/install_mathlibs.sh
+    ./scripts/install_fftw.sh
+    ./scripts/install_spfft.sh
+    ./scripts/install_libint.sh
+    ./scripts/install_libxc.sh
+    ./scripts/install_libsmm.sh
+    ./scripts/install_libxsmm.sh
+    ./scripts/install_scalapack.sh
+    ./scripts/install_elpa.sh
+    ./scripts/install_ptscotch.sh
+    ./scripts/install_parmetis.sh
+    ./scripts/install_metis.sh
+    ./scripts/install_superlu.sh
+    ./scripts/install_pexsi.sh
+    ./scripts/install_quip.sh
+    ./scripts/install_plumed.sh
+    ./scripts/install_gsl.sh
+    ./scripts/install_spglib.sh
+    ./scripts/install_hdf5.sh
+    ./scripts/install_libvdwxc.sh
+    ./scripts/install_sirius.sh
+    ./scripts/generate_arch_files.sh
 fi
 
-export CP_CFLAGS="${CP_CFLAGS} IF_DEBUG(${REF_MATH_CFLAGS}|IF_VALGRIND(${REF_MATH_CFLAGS}|${FAST_MATH_CFLAGS}))"
-export CP_LDFLAGS="${CP_LDFLAGS} IF_DEBUG(${REF_MATH_LDFLAGS}|IF_VALGRIND(${REF_MATH_LDFLAGS}|${FAST_MATH_LDFLAGS}))"
-export CP_LIBS="${CP_LIBS} IF_DEBUG(${REF_MATH_LIBS}|IF_VALGRIND(${REF_MATH_LIBS}|${FAST_MATH_LIBS}))"
-
-# other libraries
-for ii in $lib_list ; do
-    install_mode="$(eval echo \${with_${ii}})"
-    "${SCRIPTDIR}"/install_${ii}.sh "$install_mode"
-    load "${BUILDDIR}/setup_${ii}"
-done
-
-# ------------------------------------------------------------------------
-# generate arch file for compiling cp2k
-# ------------------------------------------------------------------------
-
-echo "==================== generating arch files ===================="
-echo "arch files can be found in the ${INSTALLDIR}/arch subdirectory"
-! [ -f "${INSTALLDIR}/arch" ] && mkdir -p ${INSTALLDIR}/arch
-cd ${INSTALLDIR}/arch
-
-# -------------------------
-# set compiler flags
-# -------------------------
-
-# need to switch between FC and MPICC etc in arch file, but cannot use
-# same variable names, so use _arch suffix
-CC_arch="$CC"
-CXX_arch="$CXX"
-FC_arch="IF_MPI(${MPIFC}|${FC})"
-LD_arch="IF_MPI(${MPIFC}|${FC})"
-
-# we always want good line information and backtraces
-BASEFLAGS="-march=native -fno-omit-frame-pointer -g ${TSANFLAGS}"
-OPT_FLAGS="-O3 -funroll-loops -ffast-math"
-NOOPT_FLAGS="-O1"
-
-# those flags that do not influence code generation are used always, the others if debug
-FCDEB_FLAGS="-ffree-form -std=f2003 -fimplicit-none"
-FCDEB_FLAGS_DEBUG="-fsanitize=leak -fcheck=bounds,do,recursion,pointer -ffpe-trap=invalid,zero,overflow -finit-real=snan -fno-fast-math"
-
-# code coverage generation flags
-COVERAGE_FLAGS="-O1 -coverage -fkeep-static-functions"
-COVERAGE_DFLAGS="-D__NO_ABORT"
-
-# profile based optimization, see https://www.cp2k.org/howto:pgo
-PROFOPT_FLAGS="\$(PROFOPT)"
-
-# special flags for gfortran
-# https://gcc.gnu.org/onlinedocs/gfortran/Error-and-Warning-Options.html
-# we error out for these warnings (-Werror=uninitialized -Wno-maybe-uninitialized -> error on variables that must be used uninitialized)
-WFLAGS_ERROR="-Werror=aliasing -Werror=ampersand -Werror=c-binding-type -Werror=intrinsic-shadow -Werror=intrinsics-std -Werror=line-truncation -Werror=tabs -Werror=realloc-lhs-all -Werror=target-lifetime -Werror=underflow -Werror=unused-but-set-variable -Werror=unused-variable -Werror=unused-dummy-argument -Werror=conversion -Werror=zerotrip -Werror=uninitialized -Wno-maybe-uninitialized"
-# we just warn for those (that eventually might be promoted to WFLAGSERROR). It is useless to put something here with 100s of warnings.
-WFLAGS_WARN="-Wuse-without-only"
-# while here we collect all other warnings, some we'll ignore
-WFLAGS_WARNALL="-pedantic -Wall -Wextra -Wsurprising -Wunused-parameter -Warray-temporaries -Wcharacter-truncation -Wconversion-extra -Wimplicit-interface -Wimplicit-procedure -Wreal-q-constant -Wunused-parameter -Walign-commons -Wfunction-elimination -Wrealloc-lhs -Wcompare-reals -Wzerotrip"
-
-# IEEE_EXCEPTIONS dependency
-IEEE_EXCEPTIONS_DFLAGS="-D__HAS_IEEE_EXCEPTIONS"
-
-# check all of the above flags, filter out incompatable flags for the
-# current version of gcc in use
-BASEFLAGS=$(allowed_gfortran_flags         $BASEFLAGS)
-OPT_FLAGS=$(allowed_gfortran_flags         $OPT_FLAGS)
-NOOPT_FLAGS=$(allowed_gfortran_flags       $NOOPT_FLAGS)
-FCDEB_FLAGS=$(allowed_gfortran_flags       $FCDEB_FLAGS)
-FCDEB_FLAGS_DEBUG=$(allowed_gfortran_flags $FCDEB_FLAGS_DEBUG)
-COVERAGE_FLAGS=$(allowed_gfortran_flags    $COVERAGE_FLAGS)
-WFLAGS_ERROR=$(allowed_gfortran_flags      $WFLAGS_ERROR)
-WFLAGS_WARN=$(allowed_gfortran_flags       $WFLAGS_WARN)
-WFLAGS_WARNALL=$(allowed_gfortran_flags    $WFLAGS_WARNALL)
-
-# check if ieee_exeptions module is avaliable for the current version
-# of gfortran being used
-if ! (check_gfortran_module ieee_exceptions) ; then
-    IEEE_EXCEPTIONS_DFLAGS=""
-fi
-
-# contagnate the above flags into WFLAGS, FCDEBFLAGS, DFLAGS and
-# finally into FCFLAGS and CFLAGS
-WFLAGS="$WFLAGS_ERROR $WFLAGS_WARN IF_WARNALL(${WFLAGS_WARNALL}|)"
-FCDEBFLAGS="$FCDEB_FLAGS IF_DEBUG($FCDEB_FLAGS_DEBUG|)"
-DFLAGS="${CP_DFLAGS} IF_DEBUG($IEEE_EXCEPTIONS_DFLAGS|) IF_COVERAGE($COVERAGE_DFLAGS|)"
-# language independent flags
-# valgrind with avx can lead to spurious out-of-bound results
-G_CFLAGS="$BASEFLAGS IF_VALGRIND(-mno-avx -mno-avx2|)"
-G_CFLAGS="$G_CFLAGS IF_COVERAGE($COVERAGE_FLAGS|IF_DEBUG($NOOPT_FLAGS|$OPT_FLAGS))"
-G_CFLAGS="$G_CFLAGS IF_DEBUG(|$PROFOPT_FLAGS)"
-G_CFLAGS="$G_CFLAGS $CP_CFLAGS"
-# FCFLAGS, for gfortran
-FCFLAGS="$G_CFLAGS \$(FCDEBFLAGS) \$(WFLAGS) \$(DFLAGS)"
-# CFLAGS, spcial flags for gcc (currently none)
-CFLAGS="$G_CFLAGS \$(DFLAGS)"
-
-# Linker flags
-LDFLAGS="\$(FCFLAGS) ${CP_LDFLAGS}"
-
-# Library flags
-# add standard libs
-LIBS="${CP_LIBS} -lstdc++"
-
-# CUDA stuff
-CUDA_LIBS="-lcudart -lcufft -lcublas -lrt IF_DEBUG(-lnvToolsExt|)"
-CUDA_DFLAGS="-D__ACC -D__DBCSR_ACC -D__PW_CUDA IF_DEBUG(-D__CUDA_PROFILING|)"
-if [ "$ENABLE_CUDA" = __TRUE__ ] ; then
-    LIBS="${LIBS} IF_CUDA(${CUDA_LIBS}|)"
-    DFLAGS="IF_CUDA(${CUDA_DFLAGS}|) ${DFLAGS}"
-    NVFLAGS="-arch sm_35 \$(DFLAGS)"
-fi
-
-# -------------------------
-# generate the arch files
-# -------------------------
-
-# generator for CP2K ARCH files
-gen_arch_file() {
-    # usage: gen_arch_file file_name flags
-    #
-    # If the flags are present they are assumed to be on, otherwise
-    # they switched off
-    require_env ARCH_FILE_TEMPLATE
-    local __filename=$1
-    shift
-    local __flags=$@
-    local __full_flag_list="MPI OMP DEBUG CUDA WARNALL VALGRIND COVERAGE"
-    local __flag=''
-    for __flag in $__full_flag_list ; do
-        eval "local __${__flag}=off"
-    done
-    for __flag in $__flags ; do
-        eval "__${__flag}=on"
-    done
-    # generate initial arch file
-    cat $ARCH_FILE_TEMPLATE > $__filename
-    # add additional parts
-    if [ "$__CUDA" = "on" ] ; then
-      cat <<EOF >> $__filename
-#
-NVCC        = \${NVCC} -D__GNUC__=4 -D__GNUC_MINOR__=9 -Xcompiler=--std=gnu++98
-NVFLAGS     = \${NVFLAGS}
-EOF
-    fi
-    if [ "$__WARNALL" = "on" ] ; then
-        cat <<EOF >> $__filename
-#
-FCLOGPIPE   =  2> \\\$(notdir \\\$<).warn
-export LC_ALL=C
-EOF
-    fi
-    # replace variable values in output file using eval
-    local __TMPL=$(cat $__filename)
-    eval "printf \"${__TMPL}\n\"" > $__filename
-    # pass this to parsers to replace all of the IF_XYZ statements
-    python ${SCRIPTDIR}/parse_if.py $__filename $__flags
-    echo "Wrote ${INSTALLDIR}/arch/$__filename"
-}
-
-rm -f ${INSTALLDIR}/arch/local*
-# normal production arch files
-    { gen_arch_file "local.sopt" ;          arch_vers="sopt"; }
-    { gen_arch_file "local.sdbg" DEBUG;     arch_vers="${arch_vers} sdbg"; }
-[ "$ENABLE_OMP" = __TRUE__ ] && \
-    { gen_arch_file "local.ssmp" OMP;       arch_vers="${arch_vers} ssmp"; }
-[ "$MPI_MODE" != no ] && \
-    { gen_arch_file "local.popt" MPI;       arch_vers="${arch_vers} popt"; }
-[ "$MPI_MODE" != no ] && \
-    { gen_arch_file "local.pdbg" MPI DEBUG; arch_vers="${arch_vers} pdbg"; }
-[ "$MPI_MODE" != no ] && \
-[ "$ENABLE_OMP" = __TRUE__ ] && \
-    { gen_arch_file "local.psmp" MPI OMP;   arch_vers="${arch_vers} psmp"; }
-[ "$MPI_MODE" != no ] && \
-[ "$ENABLE_OMP" = __TRUE__ ] && \
-    gen_arch_file "local_warn.psmp" MPI OMP WARNALL
-# cuda enabled arch files
-if [ "$ENABLE_CUDA" = __TRUE__ ] ; then
-    [ "$ENABLE_OMP" = __TRUE__ ] && \
-      gen_arch_file "local_cuda.ssmp"          CUDA OMP
-    [ "$MPI_MODE" != no ] && \
-    [ "$ENABLE_OMP" = __TRUE__ ] && \
-      gen_arch_file "local_cuda.psmp"          CUDA OMP MPI
-    [ "$ENABLE_OMP" = __TRUE__ ] && \
-      gen_arch_file "local_cuda.sdbg"          CUDA DEBUG OMP
-    [ "$MPI_MODE" != no ] && \
-    [ "$ENABLE_OMP" = __TRUE__ ] && \
-      gen_arch_file "local_cuda.pdbg"          CUDA DEBUG OMP MPI
-    [ "$MPI_MODE" != no ] && \
-    [ "$ENABLE_OMP" = __TRUE__ ] && \
-      gen_arch_file "local_cuda_warn.psmp"     CUDA MPI OMP WARNALL
-fi
-# valgrind enabled arch files
-if [ "$ENABLE_VALGRIND" = __TRUE__ ] ; then
-      gen_arch_file "local_valgrind.sdbg"      VALGRIND
-    [ "$MPI_MODE" != no ] && \
-      gen_arch_file "local_valgrind.pdbg"      VALGRIND MPI
-fi
-# coverage enabled arch files
-if [ "$ENABLE_COVERAGE" = __TRUE__ ]; then
-      gen_arch_file "local_coverage.sdbg"      COVERAGE
-    [ "$MPI_MODE" != no ] && \
-      gen_arch_file "local_coverage.pdbg"      COVERAGE MPI
-    [ "$ENABLE_CUDA" = __TRUE__ ] && \
-      gen_arch_file "local_coverage_cuda.pdbg" COVERAGE MPI CUDA
-fi
-
-cd "${ROOTDIR}"
-
-# -------------------------
-# print out user instructions
-# -------------------------
-
-cat <<EOF
-========================== usage =========================
-Done!
-Now copy:
-  cp ${INSTALLDIR}/arch/* to the cp2k/arch/ directory
-To use the installed tools and libraries and cp2k version
-compiled with it you will first need to execute at the prompt:
-  source ${SETUPFILE}
-To build CP2K you should change directory:
-  cd cp2k/makefiles/
-  make -j ${NPROCS} ARCH=local VERSION="${arch_vers}"
-
-arch files for GPU enabled CUDA versions are named "local_cuda.*"
-arch files for valgrind versions are named "local_valgrind.*"
-arch files for coverage versions are named "local_coverage.*"
-EOF
-
 #EOF
