@@ -2,12 +2,13 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
+elpa_ver="2019.05.001"
+elpa_sha256="772c03dab8713ba3891b17757a0b8429b3c4bec4b261dd337ed4b34311f6b221"
 source "${SCRIPT_DIR}"/common_vars.sh
-source "${SCRIPT_DIR}"/package_versions.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
-
-with_elpa=${1:-__INSTALL__}
+source "${INSTALLDIR}"/toolchain.conf
+source "${INSTALLDIR}"/toolchain.env
 
 [ -f "${BUILDDIR}/setup_elpa" ] && rm "${BUILDDIR}/setup_elpa"
 
@@ -16,6 +17,9 @@ ELPA_LDFLAGS=''
 ELPA_LIBS=''
 ELPA_CFLAGS_OMP=''
 ELPA_LIBS_OMP=''
+# ELPA 2019.05.001 has a parallel build issue, restricting to -j1
+ELPA_MAKEOPTS='-j1'
+
 ! [ -d "${BUILDDIR}" ] && mkdir -p "${BUILDDIR}"
 cd "${BUILDDIR}"
 
@@ -33,14 +37,14 @@ case "$with_elpa" in
         echo "==================== Installing ELPA ===================="
         pkg_install_dir="${INSTALLDIR}/elpa-${elpa_ver}"
         install_lock_file="$pkg_install_dir/install_successful"
-        if [ -f "${install_lock_file}" ] ; then
+        if verify_checksums "${install_lock_file}" ; then
             echo "elpa-${elpa_ver} is already installed, skipping it."
         else
             require_env MATH_LIBS
             if [ -f elpa-${elpa_ver}.tar.gz ] ; then
                 echo "elpa-${elpa_ver}.tar.gz is found"
             else
-                download_pkg ${DOWNLOADER_FLAGS} \
+                download_pkg ${DOWNLOADER_FLAGS} ${elpa_sha256} \
                              https://www.cp2k.org/static/downloads/elpa-${elpa_ver}.tar.gz
             fi
             [ -d elpa-${elpa_ver} ] && rm -rf elpa-${elpa_ver}
@@ -56,70 +60,77 @@ case "$with_elpa" in
             # elpa expect FC to be an mpi fortran compiler that is happy
             # with long lines, and that a bunch of libs can be found
             cd elpa-${elpa_ver}
-            # shared libraries cannot be built if linked with
-            # reflapack (the case when valgrind is enabled)
-            if [ "$ENABLE_VALGRIND" = "__TRUE__" ] ; then
-                shared_flag=no
-            else
-                shared_flag=yes
-            fi
             # specific settings needed on CRAY Linux Environment
             if [ "$ENABLE_CRAY" = "__TRUE__" ] ; then
                 # extra LDFLAGS needed
                 cray_ldflags="-dynamic"
             fi
             # ELPA-2017xxxx enables AVX2 by default, switch off if machine doesn't support it.
-            # In addition, --disable-option-checking is needed for older versions, which don't know
-            # about this option.
-            has_AVX2=`grep 'avx2' /proc/cpuinfo 1>/dev/null && echo 'yes' || echo 'no'`
-            has_AVX512=`grep 'avx512' /proc/cpuinfo 1>/dev/null && echo 'yes' || echo 'no'`
+            has_AVX=`grep '\bavx\b' /proc/cpuinfo 1>/dev/null && echo 'yes' || echo 'no'`
+            [ "${has_AVX}" == "yes" ] && AVX_flag="-mavx" || AVX_flag=""
+            has_AVX2=`grep '\bavx2\b' /proc/cpuinfo 1>/dev/null && echo 'yes' || echo 'no'`
+            [ "${has_AVX2}" == "yes" ] && AVX_flag="-mavx2"
+            has_AVX512=`grep '\bavx512f\b' /proc/cpuinfo 1>/dev/null && echo 'yes' || echo 'no'`
+            [ "${has_AVX512}" == "yes" ] && AVX512_flags="-mavx512f"
+            has_GPU=$([ "$ENABLE_CUDA" == "__TRUE__" ] && echo "yes" || echo "no")
+            FMA_flag=`grep '\bfma\b' /proc/cpuinfo 1>/dev/null && echo '-mfma' || echo '-mno-fma'`
+            SSE4_flag=`grep '\bsse4_1\b' /proc/cpuinfo 1>/dev/null && echo '-msse4' || echo '-mno-sse4'`
+            grep '\bavx512dq\b' /proc/cpuinfo 1>/dev/null && AVX512_flags+=" -mavx512dq"
+            grep '\bavx512cd\b' /proc/cpuinfo 1>/dev/null && AVX512_flags+=" -mavx512cd"
+            grep '\bavx512bw\b' /proc/cpuinfo 1>/dev/null && AVX512_flags+=" -mavx512bw"
+            grep '\bavx512v1\b' /proc/cpuinfo 1>/dev/null && AVX512_flags+=" -mavx512v1"
             # non-threaded version
             mkdir -p obj_no_thread; cd obj_no_thread
-            ../configure  --prefix=${pkg_install_dir} \
+            ../configure  --prefix="${pkg_install_dir}" \
                           --libdir="${pkg_install_dir}/lib" \
                           --enable-openmp=no \
-                          --enable-shared=$shared_flag \
+                          --enable-shared=no \
                           --enable-static=yes \
-                          --disable-option-checking \
+                          --enable-avx=${has_AVX} \
                           --enable-avx2=${has_AVX2} \
                           --enable-avx512=${has_AVX512} \
+                          --enable-gpu=${has_GPU} \
+                          --with-cuda-path=${CUDA_PATH} \
                           FC=${MPIFC} \
                           CC=${MPICC} \
                           CXX=${MPICXX} \
-                          FCFLAGS="${FCFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} -ffree-line-length-none" \
-                          CFLAGS="${CFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS}" \
-                          CXXFLAGS="${CXXFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS}" \
+                          FCFLAGS="${FCFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} -ffree-line-length-none ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
+                          CFLAGS="${CFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
+                          CXXFLAGS="${CXXFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
                           LDFLAGS="-Wl,--enable-new-dtags ${MATH_LDFLAGS} ${SCALAPACK_LDFLAGS} ${cray_ldflags}" \
-                          LIBS="${SCALAPACK_LIBS} ${MATH_LIBS}" \
-                          > configure.log 2>&1
-            make -j $NPROCS >  make.log 2>&1
+                          LIBS="${SCALAPACK_LIBS} $(resolve_string "${MATH_LIBS}")" \
+                          >configure.log 2>&1
+            make -j $NPROCS ${ELPA_MAKEOPTS} >make.log 2>&1
             make install > install.log 2>&1
             cd ..
             # threaded version
             if [ "$ENABLE_OMP" = "__TRUE__" ] ; then
                 mkdir -p obj_thread; cd obj_thread
-                ../configure  --prefix=${pkg_install_dir} \
+                ../configure  --prefix="${pkg_install_dir}" \
+                              --libdir="${pkg_install_dir}/lib" \
                               --enable-openmp=yes \
-                              --enable-shared=$shared_flag \
+                              --enable-shared=no \
                               --enable-static=yes \
-                              --disable-option-checking \
+                              --enable-avx=${has_AVX} \
                               --enable-avx2=${has_AVX2} \
                               --enable-avx512=${has_AVX512} \
+                              --enable-gpu=${has_GPU} \
+                              --with-cuda-path=${CUDA_PATH} \
                               FC=${MPIFC} \
                               CC=${MPICC} \
                               CXX=${MPICXX} \
-                              FCFLAGS="${FCFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} -ffree-line-length-none" \
-                              CFLAGS="${CFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS}" \
-                              CXXFLAGS="${CXXFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS}" \
+                              FCFLAGS="${FCFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} -ffree-line-length-none ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
+                              CFLAGS="${CFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
+                              CXXFLAGS="${CXXFLAGS} ${MATH_CFLAGS} ${SCALAPACK_CFLAGS} ${AVX_flag} ${FMA_flag} ${SSE4_flag} ${AVX512_flags}" \
                               LDFLAGS="-Wl,--enable-new-dtags ${MATH_LDFLAGS} ${SCALAPACK_LDFLAGS} ${cray_ldflags}" \
-                              LIBS="${SCALAPACK_LIBS} ${MATH_LIBS}" \
-                              > configure.log 2>&1
-                make -j $NPROCS >  make.log 2>&1
-                make install > install.log 2>&1
+                              LIBS="${SCALAPACK_LIBS} $(resolve_string "${MATH_LIBS}" OMP)" \
+                              >configure.log 2>&1
+                make -j $NPROCS ${ELPA_MAKEOPTS} >make.log 2>&1
+                make install >install.log 2>&1
                 cd ..
             fi
             cd ..
-            touch "${install_lock_file}"
+            write_checksums "${install_lock_file}" "${SCRIPT_DIR}/$(basename ${SCRIPT_NAME})"
         fi
         ELPA_CFLAGS="-I'${pkg_install_dir}/include/elpa-${elpa_ver}/modules' -I'${pkg_install_dir}/include/elpa-${elpa_ver}/elpa'"
         ELPA_CFLAGS_OMP="-I'${pkg_install_dir}/include/elpa_openmp-${elpa_ver}/modules' -I'${pkg_install_dir}/include/elpa_openmp-${elpa_ver}/elpa'"
@@ -195,6 +206,7 @@ prepend_path PATH "$pkg_install_dir/bin"
 prepend_path LD_LIBRARY_PATH "$pkg_install_dir/lib"
 prepend_path LD_RUN_PATH "$pkg_install_dir/lib"
 prepend_path LIBRARY_PATH "$pkg_install_dir/lib"
+export ELPAROOT="$pkg_install_dir"
 EOF
     fi
     cat "${BUILDDIR}/setup_elpa" >> $SETUPFILE
@@ -205,10 +217,19 @@ export ELPA_LIBS="${ELPA_LIBS}"
 export ELPA_CFLAGS_OMP="${ELPA_CFLAGS_OMP}"
 export ELPA_LDFLAGS_OMP="${ELPA_LDFLAGS_OMP}"
 export ELPA_LIBS_OMP="${ELPA_LIBS_OMP}"
-export CP_DFLAGS="\${CP_DFLAGS} IF_MPI(-D__ELPA=${elpa_ver:0:4}${elpa_ver:5:2}|)"
+export CP_DFLAGS="\${CP_DFLAGS} IF_MPI(-D__ELPA|)"
 export CP_CFLAGS="\${CP_CFLAGS} IF_MPI(IF_OMP(${ELPA_CFLAGS_OMP}|${ELPA_CFLAGS})|)"
 export CP_LDFLAGS="\${CP_LDFLAGS} IF_MPI(${ELPA_LDFLAGS}|)"
 export CP_LIBS="IF_MPI(IF_OMP(${ELPA_LIBS_OMP}|${ELPA_LIBS})|) \${CP_LIBS}"
+prepend_path PKG_CONFIG_PATH "$pkg_install_dir/lib/pkgconfig"
+export ELPAROOT="$pkg_install_dir"
+export ELPAVERSION="${elpa_ver}"
 EOF
 fi
+
+# update toolchain environment
+load "${BUILDDIR}/setup_elpa"
+export -p > "${INSTALLDIR}/toolchain.env"
+
 cd "${ROOTDIR}"
+report_timing "elpa"
