@@ -2,12 +2,13 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
+libxsmm_ver="1.14"
+libxsmm_sha256="9c0af4509ea341d1ee2c6c19fc6f19289318c3bd4b17844efeb9e7f9691abf76"
 source "${SCRIPT_DIR}"/common_vars.sh
-source "${SCRIPT_DIR}"/package_versions.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
-
-with_libxsmm=${1:-__INSTALL__}
+source "${INSTALLDIR}"/toolchain.conf
+source "${INSTALLDIR}"/toolchain.env
 
 [ -f "${BUILDDIR}/setup_libxsmm" ] && rm "${BUILDDIR}/setup_libxsmm"
 
@@ -16,11 +17,12 @@ LIBXSMM_LDFLAGS=''
 LIBXSMM_LIBS=''
 ! [ -d "${BUILDDIR}" ] && mkdir -p "${BUILDDIR}"
 cd "${BUILDDIR}"
+
 case "$with_libxsmm" in
     __INSTALL__)
         echo "==================== Installing Libxsmm ===================="
         if [ "$OPENBLAS_ARCH" != "x86_64" ] ; then
-            report_warning $LINENO "libxsmm not suported on arch ${OPENBLAS_ARCH}"
+            report_warning $LINENO "libxsmm is not supported on arch ${OPENBLAS_ARCH}"
             cat <<EOF > "${BUILDDIR}/setup_libxsmm"
 with_libxsmm="__DONTUSE__"
 EOF
@@ -28,7 +30,7 @@ EOF
         fi
         pkg_install_dir="${INSTALLDIR}/libxsmm-${libxsmm_ver}"
         install_lock_file="$pkg_install_dir/install_successful"
-        if [ -f "${install_lock_file}" ] ; then
+        if verify_checksums "${install_lock_file}" ; then
             echo "libxsmm-${libxsmm_ver} is already installed, skipping it."
         else
             if [ "$libxsmm_ver" = "master" ] ; then
@@ -41,7 +43,7 @@ EOF
                 if [ -f libxsmm-${libxsmm_ver}.tar.gz ] ; then
                     echo "libxsmm-${libxsmm_ver}.tar.gz is found"
                 else
-                    download_pkg ${DOWNLOADER_FLAGS} \
+                    download_pkg ${DOWNLOADER_FLAGS} ${libxsmm_sha256} \
                                  https://www.cp2k.org/static/downloads/libxsmm-${libxsmm_ver}.tar.gz
                 fi
                 [ -d libxsmm-${libxsmm_ver} ] && rm -rf libxsmm-${libxsmm_ver}
@@ -55,24 +57,22 @@ EOF
             # stage of building an executable that uses the libxsmm
             # library
             cd libxsmm-${libxsmm_ver}
-            # we rely on the jit, but as it is not available for SSE,
-            # we also generate a subset statically.
             make -j $NPROCS \
+                 MALLOC=0 \
                  CXX=$CXX \
                  CC=$CC \
                  FC=$FC \
-                 MNK="1 4 5 6 8 9 13 16 17 22 23 24 26 32" \
                  PREFIX=${pkg_install_dir} \
                  > make.log 2>&1
             make -j $NPROCS \
+                 MALLOC=0 \
                  CXX=$CXX \
                  CC=$CC \
                  FC=$FC \
-                 MNK="1 4 5 6 8 9 13 16 17 22 23 24 26 32" \
                  PREFIX=${pkg_install_dir} \
                  install > install.log 2>&1
             cd ..
-            touch "${install_lock_file}"
+            write_checksums "${install_lock_file}" "${SCRIPT_DIR}/$(basename ${SCRIPT_NAME})"
         fi
         LIBXSMM_CFLAGS="-I'${pkg_install_dir}/include'"
         LIBXSMM_LDFLAGS="-L'${pkg_install_dir}/lib' -Wl,-rpath='${pkg_install_dir}/lib'"
@@ -119,3 +119,9 @@ export CP_LIBS="\${LIBXSMM_LIBS} \${CP_LIBS}"
 EOF
 fi
 cd "${ROOTDIR}"
+
+# update toolchain environment
+load "${BUILDDIR}/setup_libxsmm"
+export -p > "${INSTALLDIR}/toolchain.env"
+
+report_timing "libxsmm"
