@@ -2,13 +2,15 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
+openmpi_ver="4.0.1"
+openmpi_sha256="e55e213fe09a214ab9f2c722acfd8bf7b39bbc1800e4b7a464d38df15e707f59"
 source "${SCRIPT_DIR}"/common_vars.sh
-source "${SCRIPT_DIR}"/package_versions.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
+source "${INSTALLDIR}"/toolchain.conf
+source "${INSTALLDIR}"/toolchain.env
 
-with_openmpi=${1:-__INSTALL__}
-
+[ ${MPI_MODE} != "openmpi" ] && exit 0
 [ -f "${BUILDDIR}/setup_openmpi" ] && rm "${BUILDDIR}/setup_openmpi"
 
 OPENMPI_CFLAGS=''
@@ -16,19 +18,20 @@ OPENMPI_LDFLAGS=''
 OPENMPI_LIBS=''
 ! [ -d "${BUILDDIR}" ] && mkdir -p "${BUILDDIR}"
 cd "${BUILDDIR}"
+
 case "$with_openmpi" in
     __INSTALL__)
         echo "==================== Installing OpenMPI ===================="
         pkg_install_dir="${INSTALLDIR}/openmpi-${openmpi_ver}"
         install_lock_file="$pkg_install_dir/install_successful"
-        if [ -f "${install_lock_file}" ] ; then
+        if verify_checksums "${install_lock_file}" ; then
             echo "openmpi-${openmpi_ver} is already installed, skipping it."
         else
             if [ -f openmpi-${openmpi_ver}.tar.gz ] ; then
                 echo "openmpi-${openmpi_ver}.tar.gz is found"
             else
-                download_pkg ${DOWNLOADER_FLAGS} \
-                             https://www.cp2k.org/static/downloads/openmpi-${openmpi_ver}.tar.gz
+                download_pkg ${DOWNLOADER_FLAGS} ${openmpi_sha256} \
+                             "https://www.cp2k.org/static/downloads/openmpi-${openmpi_ver}.tar.gz"
             fi
             echo "Installing from scratch into ${pkg_install_dir}"
             [ -d openmpi-${openmpi_ver} ] && rm -rf openmpi-${openmpi_ver}
@@ -38,18 +41,18 @@ case "$with_openmpi" in
             # we need to add the -fgnu89-inline to CFLAGS. We can check
             # the version of glibc using ldd --version, as ldd is part of
             # glibc package
-            glibc_version=$(ldd --version | awk '(NR == 1){print $4}')
-            glibc_major_ver=$(echo $glibc_version | cut -d . -f 1)
-            glibc_minor_ver=$(echo $glibc_version | cut -d . -f 2)
+            glibc_version=$(ldd --version | awk '/ldd/{print $NF}')
+            glibc_major_ver=${glibc_version%%.*}
+            glibc_minor_ver=${glibc_version##*.}
             if [ $glibc_major_ver -lt 2 ] || \
                [ $glibc_major_ver -eq 2 -a $glibc_minor_ver -lt 12 ] ; then
                 CFLAGS="${CFLAGS} -fgnu89-inline"
             fi
-            ./configure --prefix=${pkg_install_dir} --libdir="${pkg_install_dir}/lib" CFLAGS="${CFLAGS}" > configure.log 2>&1
+            ./configure --prefix=${pkg_install_dir} --libdir="${pkg_install_dir}/lib" --enable-mpi1-compatibility CFLAGS="${CFLAGS}" > configure.log 2>&1
             make -j $NPROCS > make.log 2>&1
             make -j $NPROCS install > install.log 2>&1
             cd ..
-            touch "${install_lock_file}"
+            write_checksums "${install_lock_file}" "${SCRIPT_DIR}/$(basename ${SCRIPT_NAME})"
         fi
         OPENMPI_CFLAGS="-I'${pkg_install_dir}/include'"
         OPENMPI_LDFLAGS="-L'${pkg_install_dir}/lib' -Wl,-rpath='${pkg_install_dir}/lib'"
@@ -60,9 +63,10 @@ case "$with_openmpi" in
         check_command mpicc "openmpi"
         check_command mpif90 "openmpi"
         check_command mpic++ "openmpi"
-        check_lib -lmpi "openmpi"
-        add_include_from_paths OPENMPI_CFLAGS "mpi.h" $INCLUDE_PATHS
-        add_lib_from_paths OPENMPI_LDFLAGS "libmpi.*" $LIB_PATHS
+        # Fortran code in CP2K is built via the mpifort wrapper, but we may need additional
+        # libraries and linker flags for C/C++-based MPI codepaths, pull them in at this point.
+        OPENMPI_CFLAGS="$(mpicxx --showme:compile)"
+        OPENMPI_LDFLAGS="$(mpicxx --showme:link)"
         ;;
     __DONTUSE__)
         ;;
@@ -87,20 +91,23 @@ prepend_path CPATH "$pkg_install_dir/include"
 EOF
         cat "${BUILDDIR}/setup_openmpi" >> $SETUPFILE
         mpi_bin="$pkg_install_dir/bin/mpirun"
+        mpicxx_bin="$pkg_install_dir/bin/mpicxx"
     else
         mpi_bin=mpirun
+        mpicxx_bin=mpicxx
     fi
     # check openmpi version as reported by mpirun
     raw_version=$($mpi_bin --version 2>&1 | \
                       grep "(Open MPI)" | awk '{print $4}')
     major_version=$(echo $raw_version | cut -d '.' -f 1)
     minor_version=$(echo $raw_version | cut -d '.' -f 2)
-    # old versions required -lmpi_cxx to link cxx code, new version don't
-    if [ $major_version -gt 1 ] ; then
-       OPENMPI_LIBS="-lmpi"
-    else
-       OPENMPI_LIBS="-lmpi -lmpi_cxx"
-    fi
+    OPENMPI_LIBS=""
+    # grab additional runtime libs (for C/C++) from the mpicxx wrapper,
+    # and remove them from the LDFLAGS if present
+    for lib in $("${mpicxx_bin}" --showme:libs) ; do
+        OPENMPI_LIBS+=" -l${lib}"
+        OPENMPI_LDFLAGS="${OPENMPI_LDFLAGS//-l${lib}}"
+    done
     # old versions didn't support MPI 3, so adjust __MPI_VERSION accordingly (needed e.g. for pexsi)
     if [ $major_version -lt 1 ] || \
        [ $major_version -eq 1 -a $minor_version -lt 7 ] ; then
@@ -183,3 +190,9 @@ leak:ompi_file_open_f
 leak:progress_engine
 leak:__GI___strdup
 EOF
+
+# update toolchain environment
+load "${BUILDDIR}/setup_openmpi"
+export -p > "${INSTALLDIR}/toolchain.env"
+
+report_timing "openmpi"
