@@ -2,12 +2,13 @@
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
+superlu_ver="5.1.2"
+superlu_sha256="91032b9a4d23bd14272607b8fc9b6cbb936c385902ca4d3d0ba2d1014fbcd99d"
 source "${SCRIPT_DIR}"/common_vars.sh
-source "${SCRIPT_DIR}"/package_versions.sh
 source "${SCRIPT_DIR}"/tool_kit.sh
 source "${SCRIPT_DIR}"/signal_trap.sh
-
-with_superlu=${1:-__INSTALL__}
+source "${INSTALLDIR}"/toolchain.conf
+source "${INSTALLDIR}"/toolchain.env
 
 [ -f "${BUILDDIR}/setup_superlu" ] && rm "${BUILDDIR}/setup_superlu"
 
@@ -16,6 +17,7 @@ SUPERLU_LDFLAGS=''
 SUPERLU_LIBS=''
 ! [ -d "${BUILDDIR}" ] && mkdir -p "${BUILDDIR}"
 cd "${BUILDDIR}"
+
 case "$with_superlu" in
     __INSTALL__)
         echo "==================== Installing SuperLU_DIST ===================="
@@ -26,13 +28,13 @@ case "$with_superlu" in
         require_env MATH_LIBS
         pkg_install_dir="${INSTALLDIR}/superlu_dist-${superlu_ver}"
         install_lock_file="$pkg_install_dir/install_successful"
-        if [ -f "${install_lock_file}" ] ; then
+        if verify_checksums "${install_lock_file}" ; then
             echo "superlu_dist-${superlu_ver} is already installed, skipping it."
         else
             if [ -f superlu_dist_${superlu_ver}.tar.gz ] ; then
                 echo "superlu_dist_${superlu_ver}.tar.gz is found"
             else
-                download_pkg ${DOWNLOADER_FLAGS} \
+                download_pkg ${DOWNLOADER_FLAGS} ${superlu_sha256} \
                              https://www.cp2k.org/static/downloads/superlu_dist_${superlu_ver}.tar.gz
             fi
             echo "Installing from scratch into ${pkg_install_dir}"
@@ -40,10 +42,11 @@ case "$with_superlu" in
             tar -xzf superlu_dist_${superlu_ver}.tar.gz
             cd SuperLU_DIST_${superlu_ver}
             mv make.inc make.inc.orig
+            # using the OMP-based math libraries here (if available) for the executables since PARMETS/METIS also use OMP if available
             cat <<EOF >> make.inc
 PLAT=_${OPENBLAS_ARCH}
 DSUPERLULIB= ${PWD}/lib/libsuperlu_dist.a
-LIBS=\$(DSUPERLULIB) ${PARMETIS_LDFLAGS} ${METIS_LDFLAGS} ${MATH_LDFLAGS} ${PARMETIS_LIBS} ${METIS_LIBS} ${MATH_LIBS} -lgfortran
+LIBS=\$(DSUPERLULIB) ${PARMETIS_LDFLAGS} ${METIS_LDFLAGS} ${MATH_LDFLAGS} ${PARMETIS_LIBS} ${METIS_LIBS} $(resolve_string "${MATH_LIBS}" OMP) -lgfortran
 ARCH=ar
 ARCHFLAGS=cr
 RANLIB=ranlib
@@ -64,7 +67,7 @@ EOF
             ! [ -d "${pkg_install_dir}/include" ] && mkdir -p "${pkg_install_dir}/include"
             cp SRC/*.h "${pkg_install_dir}/include"
             cd ..
-            touch "${install_lock_file}"
+            write_checksums "${install_lock_file}" "${SCRIPT_DIR}/$(basename ${SCRIPT_NAME})"
         fi
         SUPERLU_CFLAGS="-I'${pkg_install_dir}/include'"
         SUPERLU_LDFLAGS="-L'${pkg_install_dir}/lib' -Wl,-rpath='${pkg_install_dir}/lib'"
@@ -106,4 +109,10 @@ export CP_LDFLAGS="\${CP_LDFLAGS} IF_MPI(${SUPERLU_LDFLAGS}|)"
 export CP_LIBS="IF_MPI(${SUPERLU_LIBS}|) \${CP_LIBS}"
 EOF
 fi
+
+# update toolchain environment
+load "${BUILDDIR}/setup_superlu"
+export -p > "${INSTALLDIR}"/toolchain.env
+
 cd "${ROOTDIR}"
+report_timing "superlu"
