@@ -5,6 +5,13 @@ SYS_INCLUDE_PATH=${SYS_INCLUDE_PATH:-"/usr/local/include:/usr/include"}
 SYS_LIB_PATH=${SYS_LIB_PATH:-"/user/local/lib64:/usr/local/lib:/usr/lib64:/usr/lib:/lib64:/lib"}
 INCLUDE_PATHS=${INCLUDE_PATHS:-"CPATH SYS_INCLUDE_PATH"}
 LIB_PATHS=${LIB_PATHS:-"LIBRARY_PATH LD_LIBRARY_PATH LD_RUN_PATH SYS_LIB_PATH"}
+time_start=`date +%s`
+
+# report timing
+report_timing() {
+    time_stop=`date +%s`
+    printf "Step %s took %0.2f seconds.\n" $1 $((time_stop-time_start))
+}
 
 # report a warning message with script name and line number
 report_warning() {
@@ -123,7 +130,7 @@ reverse() (
     echo "$__result"
 )
 
-# get the number of processes avaliable for compilation
+# get the number of processes available for compilation
 get_nprocs() {
     if $(command -v nproc >&- 2>&-) ; then
         echo $(nproc --all)
@@ -169,8 +176,8 @@ paths_to_ld() {
 }
 
 # Find a file from directories given in a list of paths, each has the
-# same format as env variable PATH. If the file is found, then echos
-# the full path of the file. If the file is not found, then echos
+# same format as env variable PATH. If the file is found, then echoes
+# the full path of the file. If the file is not found, then echoes
 # __FALSE__. The file name can also contain wildcards that are
 # acceptable for bash, and in that case the full path of the first
 # matching file will be echoed.
@@ -213,7 +220,7 @@ find_in_paths() {
 # directory, to the -I include list for CFLAGS and append to a user
 # specified variable (__cflags_name). If not found, then nothing is
 # done. If the option -p is present, then if the search target is a
-# directory, then the parent directory of the direcotry is used for -I
+# directory, then the parent directory of the directory is used for -I
 # instead.  The search target accepts bash wildcards, and in this case
 # the first match will be used.
 add_include_from_paths() {
@@ -242,7 +249,7 @@ add_include_from_paths() {
         __cflags="$(unique $__cflags)"
         # must escape all quotes again before the last eval, as
         # otherwise all quotes gets interpreted by the shell when
-        # assiging to variable because eval will reduce one escape
+        # assigning to variable because eval will reduce one escape
         # level
         __cflags="${__cflags//'/\\'}"
         eval $__cflags_name=\"$__cflags\"
@@ -255,7 +262,7 @@ add_include_from_paths() {
 # and append to a user specified variable (__ldflags_name). If not
 # found, then nothing is done. If the option -p is present, then if
 # the search target is a directory, then the parent directory of the
-# direcotry is used for -L instead.  The search target accepts bash
+# directory is used for -L instead.  The search target accepts bash
 # wildcards, and in this case the first match will be used.
 add_lib_from_paths() {
     local __parent_dir_only=false
@@ -283,7 +290,7 @@ add_lib_from_paths() {
         __ldflags="$(unique $__ldflags)"
         # must escape all quotes again before the last eval, as
         # otherwise all quotes gets interpreted by the shell when
-        # assiging to variable because eval will reduce one escape
+        # assigning to variable because eval will reduce one escape
         # level
         __ldflags="${__ldflags//'/\\'}"
         eval $__ldflags_name=\"$__ldflags\"
@@ -291,15 +298,24 @@ add_lib_from_paths() {
 }
 
 # check if environment variable is assigned and non-empty
+# https://serverfault.com/questions/7503/how-to-determine-if-a-bash-variable-is-empty
 require_env() {
     local __env_var_name=$1
     local __env_var="$(eval echo \"\$$__env_var_name\")"
-    if [ -z "$__env_var" ] ; then
+    if [ -z "${__env_var+set}" ] ; then
         report_error "requires environment variable $__env_var_name to work"
         return 1
     fi
 }
 
+resolve_string() {
+    local __to_resolve=$1
+    shift
+    local __flags=$@
+
+    echo $("${SCRIPTDIR}/parse_if.py" $__flags <<< "${__to_resolve}")
+}
+
 # check if a command is available
 check_command() {
     local __command=$1
@@ -339,7 +355,7 @@ check_lib() {
     fi
     # Note that LD_LIBRARY_PATH is NOT used by ld during linking
     # stage, and is only used for searching to the shared libraries
-    # requred by the executable AFTER it has already been compiled, to
+    # required by the executable AFTER it has already been compiled, to
     # override its internal search paths built into the binary when it
     # was compiled. Here, we explicitly include the commonly defined
     # library search paths---including LD_LIBRARY_PATH---in the -L
@@ -554,13 +570,13 @@ read_with() {
 # helper routine to check integrity of downloaded files
 checksum() {
    local __filename=$1
-   local __checksums=$2
+   local __sha256=$2
    local __shasum_command='sha256sum'
    # check if we have sha256sum command, Mac OS X does not have
    # sha256sum, but has an equivalent with shasum -a 256
    command -v "$__shasum_command" >&- 2>&- || \
        __shasum_command="shasum -a 256"
-   if eval "grep $__filename $__checksums | ${__shasum_command} --check" ; then
+   if echo "$__sha256  $__filename" | ${__shasum_command} --check ; then
        echo "Checksum of $__filename Ok"
    else
       rm -v ${__filename}
@@ -572,7 +588,7 @@ checksum() {
 # downloader for the package tars, excludes checksum
 download_pkg_no_checksum() {
     # usage: download_pkg_no_checksum [-n] [-o output_filename] url
-    local __wget_flags=''
+    local __wget_flags='--quiet'
     local __url=''
     while [ $# -ge 1 ] ; do
         case "$1" in
@@ -598,11 +614,11 @@ download_pkg_no_checksum() {
 
 # downloader for the package tars, includes checksum
 download_pkg() {
-    # usage: download_pkg [-n] [-o output_filename] url
-    local __wget_flags=''
+    # usage: download_pkg [-n] [-o output_filename] sha256 url
+    local __wget_flags='--quiet'
     local __filename=''
     local __url=''
-    while [ $# -ge 1 ] ; do
+    while [ $# -ge 2 ] ; do
         case "$1" in
             -n)
                 __wget_flags="$__wget_flags --no-check-certificate"
@@ -613,7 +629,9 @@ download_pkg() {
                 __filename="$1"
                ;;
             *)
-                __url="$1"
+                __sha256="$1"
+                __url="$2"
+                shift
                 ;;
         esac
         shift
@@ -621,13 +639,38 @@ download_pkg() {
     if [ "$__filename" = "" ] ; then
         __filename="$(basename $__url)"
     fi
-    # env variable for checksum file must be provided
-    require_env SHA256_CHECKSUMS
     # download
     if ! wget $__wget_flags $__url ; then
         report_error "failed to download $__url"
         return 1
     fi
     # checksum
-    checksum "$__filename" "$SHA256_CHECKSUMS"
+    checksum "$__filename" "$__sha256"
+}
+
+# verify the checksums inside the given checksum file
+verify_checksums() {
+   local __checksum_file=$1
+   local __shasum_command='sha256sum'
+
+   # check if we have sha256sum command, Mac OS X does not have
+   # sha256sum, but has an equivalent with shasum -a 256
+   command -v "$__shasum_command" >&- 2>&- || \
+       __shasum_command="shasum -a 256"
+
+   ${__shasum_command} --check "${__checksum_file}" >/dev/null 2>&1
+}
+
+# write a checksum file $1 containing checksums for each given file $2, $3, ... (plus the $VERSION_FILE)
+write_checksums() {
+   local __checksum_file=$1
+   shift # remove output file from arguments to be able to pass them along properly quoted
+   local __shasum_command='sha256sum'
+
+   # check if we have sha256sum command, Mac OS X does not have
+   # sha256sum, but has an equivalent with shasum -a 256
+   command -v "$__shasum_command" >&- 2>&- || \
+       __shasum_command="shasum -a 256"
+
+   ${__shasum_command} "${VERSION_FILE}" "$@" >"${__checksum_file}"
 }
